@@ -7,7 +7,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
 #include <KPluginMetaData>
 
@@ -19,17 +18,13 @@ class KcmKontact : public KCModule
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KcmKontact(QWidget *parent, const QVariantList &args);
-#else
-    explicit KcmKontact(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KcmKontact(QObject *parent, const KPluginMetaData &data);
 
     void load() override;
     void save() override;
 
 private:
-    QVector<KPluginMetaData> mPluginList;
+    QList<KPluginMetaData> mPluginList;
     QComboBox *const mPluginCombo;
 };
 }
