@@ -13,11 +13,10 @@
 using namespace Qt::Literals::StringLiterals;
 
 #include "iconsidepane.h"
+#include "kontactconfiguredialog.h"
 #include "prefs.h"
 #include "webengine/introductionwebenginepage.h"
 #include "webengine/introductionwebengineview.h"
-
-#include "kontactconfiguredialog.h"
 using namespace Kontact;
 #ifdef WIN32
 #include <windows.h>
@@ -129,8 +128,8 @@ void MainWindow::initGUI()
     initWidgets();
     setupActions();
 
-    KStandardAction::keyBindings(this, &MainWindow::configureShortcuts, actionCollection());
-    KStandardAction::configureToolbars(this, &MainWindow::configureToolbars, actionCollection());
+    KStandardActions::keyBindings(this, &MainWindow::configureShortcuts, actionCollection());
+    KStandardActions::configureToolbars(this, &MainWindow::configureToolbars, actionCollection());
     setXMLFile(QStringLiteral("kontactui.rc"));
 
     setStandardToolBarMenuEnabled(true);
@@ -316,7 +315,7 @@ void MainWindow::initAboutScreen()
 
 void MainWindow::setupActions()
 {
-    KStandardAction::quit(this, &MainWindow::slotQuit, actionCollection());
+    KStandardActions::quit(this, &MainWindow::slotQuit, actionCollection());
 
     mNewActions = new KActionMenu(i18nc("@title:menu create new pim items (message,calendar,to-do,etc.)", "New"), this);
     actionCollection()->addAction(QStringLiteral("action_new"), mNewActions);
@@ -348,7 +347,7 @@ void MainWindow::setupActions()
     actionCollection()->setDefaultShortcut(mShowFullScreenAction, Qt::Key_F11);
     connect(mShowFullScreenAction, &QAction::toggled, this, &MainWindow::slotFullScreen);
 
-    auto manager = new KColorSchemeManager(this);
+    auto manager = KColorSchemeManager::instance();
     actionCollection()->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
     mShowMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
@@ -366,7 +365,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
                                          i18n("<qt>This will hide the menu bar completely."
                                               " You can show it again by typing %1.</qt>",
                                               accel),
-                                         i18n("Hide menu bar"),
+                                         i18nc("@title:window", "Hide menu bar"),
                                          QStringLiteral("HideMenuBarWarning"));
             }
             menuBar()->hide();
@@ -801,7 +800,7 @@ void MainWindow::slotPreferences()
     if (!dlg) {
         dlg = new Kontact::KontactConfigureDialog(this);
         connect(dlg, &KontactSettingsDialog::configCommitted, this, [this](const QString &pluginid) {
-            if (pluginid == QStringLiteral("kcm_kontact")) {
+            if (pluginid == QLatin1String("kcm_kontact")) {
                 MainWindow::updateConfig();
             }
         });
